@@ -23,9 +23,11 @@ class GerritChange(BaseModel):
             "status",
             "created",
             "updated",
+            "submitted",
             "mergeable",
             "insertions",
             "deletions",
+            "current_revision",
             "_number",
             "owner",
             "gerrit",
