@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 # -*- coding:utf-8 -*-
 # @Author: Jialiang Shi
+from copy import deepcopy
 
 
 class ResultSet(list):
@@ -10,6 +11,7 @@ class ResultSet(list):
 class BaseModel(object):
     def __init__(self, **kwargs):
         self.attributes = ["id"]
+        self.content = None
 
     def __getattr__(self, key):
         if key in self.attributes:
@@ -21,9 +23,14 @@ class BaseModel(object):
     def parse(cls, data, **kwargs):
         """Parse a JSON object into a model instance."""
         data = data or {}
+
         item = cls() if data else None
-        # setattr(item, "json", data)
+
+        content = deepcopy(data)
+        setattr(item, "content", content)
+
         data.update(kwargs)
+
         for key, value in data.items():
             if key in item.attributes:
                 setattr(item, key, value)
@@ -39,6 +46,16 @@ class BaseModel(object):
                 results.append(cls.parse(obj, **kwargs))
         return results
 
+    @classmethod
+    def parse_dict(cls, data, **kwargs):
+        """Parse a dict of JSON objects into a result set of model instances."""
+        results = ResultSet()
+        data = data or {}
+        for obj in data.keys():
+            if obj:
+                results.append(cls.parse(data[obj], **kwargs))
+        return results
+
     def __repr__(self):
         key = self.attributes[0]
         value = getattr(self, key)
